#
# spec file for package pcm
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pcm
Version:        202201
Release:        bp154.1.20
Summary:        Processor Counter Monitor
License:        BSD-3-Clause
URL:            https://github.com/opcm/pcm
Source:         https://github.com/opcm/pcm/archive/%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  cmake
ExclusiveArch:  %{ix86} x86_64

%description
Processor Counter Monitor (PCM) is an application programming interface (API)
and a set of tools based on the API to monitor performance and energy metrics
of Intel Core, Xeon, Atom and Xeon Phi processors.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%cmake -DCMAKE_BUILD_TYPE=CUSTOM -DCMAKE_INSTALL_PREFIX=%{_prefix}
%{!?cmake_build:%define cmake_build %{__cmake}}
%cmake_build

%install
%cmake_install

%files
%license LICENSE
%doc doc/*HOWTO*
%{_sbindir}/pcm
%{_sbindir}/pcm-core
%{_sbindir}/pcm-iio
%{_sbindir}/pcm-latency
%{_sbindir}/pcm-lspci
%{_sbindir}/pcm-memory
%{_sbindir}/pcm-msr
%{_sbindir}/pcm-mmio
%{_sbindir}/pcm-numa
%{_sbindir}/pcm-pcicfg
%{_sbindir}/pcm-pcie
%{_sbindir}/pcm-power
%{_sbindir}/pcm-sensor
%{_sbindir}/pcm-tsx
%{_bindir}/pcm-client
%{_sbindir}/pcm-bw-histogram
%{_sbindir}/pcm-daemon
%{_sbindir}/pcm-sensor-server
%{_sbindir}/pcm-raw
%dir %{_datadir}/pcm
%{_datadir}/pcm/opCode-106.txt
%{_datadir}/pcm/opCode-85.txt
%{_datadir}/pcm/opCode-134.txt

%changelog
* Fri Jan 28 2022 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202201 upstream version:
  * use cmake to build the project
  * reduce pcm overhead
  * pcm-raw: add -r option (PMU reset)
  * pcm-raw: add a sample separator option
  * freeze/unfreeze all core PMU counters during the read operation
  * change ulimit recommendations
  * various performance and bug fixes
* Sun Dec 26 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202112:
  * pcm: expose DRAM_GT_REQUESTS and DRAM_IA_REQUESTS bandwdith metrics
  * pcm: added client IO and GT bandwidth metrics to CSV output
  * pcm-memory: added -u option (clear screen before stat update)
  * pcm-memory: added -s option (silent mode)
  * pcm-memory: add csv print support for DRAM rank monitoring
  * pcm-memory: disable pmem output when rank monitoring is enabled
  * pcm-power: support for <1 sec delay
  * pcm-raw: added -i option (limits the number of iterations/samples)
  * pcm-raw: add support of IRP events
  * pcm-raw: add thousand separator and tab separator options
  * pcm-pcie: support 8 socket platforms
  * pcm-power: add core power license statistics
  * various small fixes and enhancements
* Sat Oct 30 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202110:
  * support ADL (Alder Lake) in pcm tool
  * display average uncore frequency in pcm.x
  * allow verbose CPU topology printing with PCM_PRINT_TOPOLOGY environment variables
  * pcm-raw: support event group multiplexing
  * pcm-iio: support csv output
  * developed a workaround to make PCM work in VMware guest
  * various bug fixes
* Sun Jul 25 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202107:
  * support systems with > 1024 logical cores
  * support Rocket Lake
  * pcm-pcie: fix HIT metrics calculation on Broadwell/Haswell server platforms
  * pcm: add several additional columns to the socket and core sections in csv output
  * pcm-iio: fix multiplier value for outbound events on Snowridge and Icelake server platforms
  * implement workaround for Linux watchdog not clearing its event programming
  * move Icelake top-down events to a separate group to fix counting through Linux perf API
  * added pcm-mmio utility to rpm
* Tue May 25 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202105:
  * support Intel Atom Processor P5900 Series (previously codenamed SnowRidge)
  * address Linux warnings
* Tue May  4 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202104:
  * Add Icelake server support
* Sat Feb 20 2021 Roman Dementiev <roman.dementiev@intel.com>
- Update to 202101:
  * Add Comet Lake support
  * Add Tiger Lake support
  * Add support for additional Icelake cpu model
  * Support Linux resctrl driver for RDT Metrics (see ENVVAR_README.md)
  * Improve robustness in handling rare core event overflows
  * A few fixes for c_example
  * Support using Linux perf API for core PMU for systems with offlined cores
  * Add -i parameter to more tools
  * support select metrics in virtual machines with vPMU support (e.g. AWS virtualized instances with arch_perfmon flag). Screenshot of grafana dashboard with PCM data from a c5.9xlarge virtualized AWS instance
  * pcm-iio: fix VT-d events on SKX
  * pcm-memory: make -pmm/-pmem the default option on systems with PMM/PMem support
  * pcm-tsx: update events for ICL and SKL, allow collection of up to 8 events
  * pcm-raw: support fixed PMU counters
  * fix UBOX MSR addresses for Jaketown/Ivytown
  * support Icelake client CPUs
  * new pcm-raw utility: to program arbitrary core and uncore events by specifying raw register event ID encoding
  * pcm-memory: support -all option to show channels event if they do not have any traffic (inactive memory channels)
  * pcm-memory: csv output for Near Memory hit rate (in PMem Memory Mode)
  * pcm-memory: show memory channels with PMM but w/o DRAM DIMMs
  * unfreeze counters using global uncore counter control register during uncore PMU initialization (some other tools freeze using global control before exit)
* Thu Aug 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 202007:
  * no upstream changelog
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build only for %%ix86 x86_64 as it targets Intel CPU only
* Mon Apr 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove the TM/etc. blurbs
* Thu Apr 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, jsc#6867
